Enum solana_exchange_program::exchange_state::OrderSide [−][src]
pub enum OrderSide {
Ask,
Bid,
}Expand description
side of the exchange between two tokens in a pair
Variants
Offer the Base asset and Accept the Quote asset
Offer the Quote asset and Accept the Base asset