OrderInfo

Struct OrderInfo 

pub struct OrderInfo {
    pub owner: Pubkey,
    pub side: OrderSide,
    pub pair: AssetPair,
    pub tokens: u64,
    pub price: u64,
    pub tokens_settled: u64,
}
Trade accounts are populated with this structure

Fields

owner: Pubkey

Owner of the trade order

side: OrderSide

side of the order in the market (bid/ask)

pair: AssetPair

Token pair indicating two tokens to exchange, first is primary

tokens: u64

Number of tokens to exchange; primary or secondary depending on side. Once this number goes to zero this trade order will be converted into a regular token account

price: u64

Scaled price of the secondary token given the primary is equal to the scale value If scale is 1 and price is 2 then ratio is 1:2 or 1 primary token for 2 secondary tokens

tokens_settled: u64

Number of tokens that have been settled so far. These nay be transferred to another token account by the owner.

Implementations

Source

impl OrderInfo

pub fn pair(self, pair: AssetPair) -> Self

pub fn side(self, side: OrderSide) -> Self

pub fn tokens(self, tokens: u64) -> Self

pub fn price(self, price: u64) -> Self