pub struct OrderInfo {
pub owner: Pubkey,
pub side: OrderSide,
pub pair: AssetPair,
pub tokens: u64,
pub price: u64,
pub tokens_settled: u64,
}Expand description
Trade accounts are populated with this structure
Fields
owner: PubkeyOwner of the trade order
side: OrderSideside of the order in the market (bid/ask)
pair: AssetPairToken pair indicating two tokens to exchange, first is primary
tokens: u64Number of tokens to exchange; primary or secondary depending on side. Once this number goes to zero this trade order will be converted into a regular token account
price: u64Scaled price of the secondary token given the primary is equal to the scale value If scale is 1 and price is 2 then ratio is 1:2 or 1 primary token for 2 secondary tokens
tokens_settled: u64Number of tokens that have been settled so far. These nay be transferred to another token account by the owner.
Implementations